@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -29,8 +29,8 @@ from pymc.distributions.distribution import (
     DiracDelta,
     Distribution,
     SymbolicRandomVariable,
-    _moment,
-    moment,
+    _support_point,
+    support_point,
 )
 from pymc.distributions.shape_utils import _change_dist_size, change_dist_size
 from pymc.distributions.transforms import _default_transform
@@ -38,7 +38,6 @@ from pymc.distributions.truncated import Truncated
 from pymc.logprob.abstract import _logcdf, _logcdf_helper, _logprob
 from pymc.logprob.basic import logp
 from pymc.logprob.transforms import IntervalTransform
-from pymc.pytensorf import floatX
 from pymc.util import check_dist_not_registered
 from pymc.vartypes import continuous_types, discrete_types
 
@@ -297,10 +296,17 @@ class Mixture(Distribution):
         # Output mix_indexes rng update so that it can be updated in place
         mix_indexes_rng_next_ = mix_indexes_.owner.outputs[0]
 
+        s = ",".join(f"s{i}" for i in range(components[0].owner.op.ndim_supp))
+        if len(components) == 1:
+            comp_s = ",".join((*s, "w"))
+            signature = f"(),(w),({comp_s})->({s})"
+        else:
+            comps_s = ",".join(f"({s})" for _ in components)
+            signature = f"(),(w),{comps_s}->({s})"
         mix_op = MarginalMixtureRV(
             inputs=[mix_indexes_rng_, weights_, *components_],
             outputs=[mix_indexes_rng_next_, mix_out_],
-            ndim_supp=components[0].owner.op.ndim_supp,
+            signature=signature,
         )
 
         # Create the actual MarginalMixture variable
@@ -315,7 +321,7 @@ class Mixture(Distribution):
             # axis intact, because that's what determines the number of mixture components
             mix_axis = -components[0].owner.op.ndim_supp - 1
             mix_size = components[0].shape[mix_axis]
-            size = tuple(size) + (mix_size,)
+            size = (*size, mix_size)
 
         return [change_dist_size(component, size) for component in components]
 
@@ -392,25 +398,25 @@ def marginal_mixture_logcdf(op, value, rng, weights, *components, **kwargs):
     return mix_logcdf
 
 
-@_moment.register(MarginalMixtureRV)
-def marginal_mixture_moment(op, rv, rng, weights, *components):
+@_support_point.register(MarginalMixtureRV)
+def marginal_mixture_support_point(op, rv, rng, weights, *components):
     ndim_supp = components[0].owner.op.ndim_supp
     weights = pt.shape_padright(weights, ndim_supp)
     mix_axis = -ndim_supp - 1
 
     if len(components) == 1:
-        moment_components = moment(components[0])
+        support_point_components = support_point(components[0])
 
     else:
-        moment_components = pt.stack(
-            [moment(component) for component in components],
+        support_point_components = pt.stack(
+            [support_point(component) for component in components],
             axis=mix_axis,
         )
 
-    mix_moment = pt.sum(weights * moment_components, axis=mix_axis)
+    mix_support_point = pt.sum(weights * support_point_components, axis=mix_axis)
     if components[0].dtype in discrete_types:
-        mix_moment = pt.round(mix_moment)
-    return mix_moment
+        mix_support_point = pt.round(mix_support_point)
+    return mix_support_point
 
 
 # List of transforms that can be used by Mixture, either because they do not require
@@ -565,7 +571,7 @@ def _zero_inflated_mixture(*, name, nonzero_p, nonzero_dist, **kwargs):
 
     If name is `None`, this function returns an unregistered variable
     """
-    nonzero_p = pt.as_tensor_variable(floatX(nonzero_p))
+    nonzero_p = pt.as_tensor_variable(nonzero_p)
     weights = pt.stack([1 - nonzero_p, nonzero_p], axis=-1)
     comp_dists = [
         DiracDelta.dist(0),
@@ -623,7 +629,7 @@ class ZeroInflatedPoisson:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of Poisson variates (0 < psi < 1)
+        Expected proportion of Poisson draws (0 < psi < 1)
     mu : tensor_like of float
         Expected number of occurrences during the given interval
         (mu >= 0).
@@ -686,7 +692,7 @@ class ZeroInflatedBinomial:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of Binomial variates (0 < psi < 1)
+        Expected proportion of Binomial draws (0 < psi < 1)
     n : tensor_like of int
         Number of Bernoulli trials (n >= 0).
     p : tensor_like of float
@@ -773,7 +779,7 @@ class ZeroInflatedNegativeBinomial:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of NegativeBinomial variates (0 < psi < 1)
+        Expected proportion of NegativeBinomial draws (0 < psi < 1)
     mu : tensor_like of float
         Poisson distribution parameter (mu > 0).
     alpha : tensor_like of float
@@ -819,7 +825,7 @@ def _hurdle_mixture(*, name, nonzero_p, nonzero_dist, dtype, **kwargs):
     else:
         raise ValueError("dtype must be 'float' or 'int'")
 
-    nonzero_p = pt.as_tensor_variable(floatX(nonzero_p))
+    nonzero_p = pt.as_tensor_variable(nonzero_p)
     weights = pt.stack([1 - nonzero_p, nonzero_p], axis=-1)
     comp_dists = [
         DiracDelta.dist(zero),
@@ -861,7 +867,7 @@ class HurdlePoisson:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of Poisson variates (0 < psi < 1)
+        Expected proportion of Poisson draws (0 < psi < 1)
     mu : tensor_like of float
         Expected number of occurrences (mu >= 0).
     """
@@ -905,7 +911,7 @@ class HurdleNegativeBinomial:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of Negative Binomial variates (0 < psi < 1)
+        Expected proportion of Negative Binomial draws (0 < psi < 1)
     alpha : tensor_like of float
         Gamma distribution shape parameter (alpha > 0).
     mu : tensor_like of float
@@ -957,7 +963,7 @@ class HurdleGamma:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of Gamma variates (0 < psi < 1)
+        Expected proportion of Gamma draws (0 < psi < 1)
     alpha : tensor_like of float, optional
         Shape parameter (alpha > 0).
     beta : tensor_like of float, optional
@@ -1009,7 +1015,7 @@ class HurdleLogNormal:
     Parameters
     ----------
     psi : tensor_like of float
-        Expected proportion of LogNormal variates (0 < psi < 1)
+        Expected proportion of LogNormal draws (0 < psi < 1)
     mu : tensor_like of float, default 0
         Location parameter.
     sigma : tensor_like of float, optional
