@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -30,8 +30,8 @@ from pymc.distributions.continuous import Normal, get_tau_sigma
 from pymc.distributions.distribution import (
     Distribution,
     SymbolicRandomVariable,
-    _moment,
-    moment,
+    _support_point,
+    support_point,
 )
 from pymc.distributions.multivariate import MvNormal, MvStudentT
 from pymc.distributions.shape_utils import (
@@ -43,7 +43,7 @@ from pymc.distributions.shape_utils import (
 from pymc.exceptions import NotConstantValueError
 from pymc.logprob.abstract import _logprob
 from pymc.logprob.basic import logp
-from pymc.pytensorf import constant_fold, floatX, intX
+from pymc.pytensorf import constant_fold, intX
 from pymc.util import check_dist_not_registered
 
 __all__ = [
@@ -195,12 +195,17 @@ class RandomWalk(Distribution):
         # shape = (B, T, S)
         grw_ = pt.concatenate([init_dist_dimswapped_, innovation_dist_dimswapped_], axis=-ndim_supp)
         grw_ = pt.cumsum(grw_, axis=-ndim_supp)
+
+        innov_supp_dims = [f"d{i}" for i in range(dist_ndim_supp)]
+        innov_supp_str = ",".join(innov_supp_dims)
+        out_supp_str = ",".join(["t", *innov_supp_dims])
+        signature = f"({innov_supp_str}),({innov_supp_str}),(s)->({out_supp_str})"
         return RandomWalkRV(
             [init_dist_, innovation_dist_, steps_],
             # We pass steps_ through just so we can keep a reference to it, even though
             # it's no longer needed at this point
-            [grw_, steps_],
-            ndim_supp=ndim_supp,
+            [grw_],
+            signature=signature,
         )(init_dist, innovation_dist, steps)
 
 
@@ -214,18 +219,18 @@ def change_random_walk_size(op, dist, new_size, expand):
     return RandomWalk.rv_op(init_dist, innovation_dist, steps, size=new_size)
 
 
-@_moment.register(RandomWalkRV)
-def random_walk_moment(op, rv, init_dist, innovation_dist, steps):
+@_support_point.register(RandomWalkRV)
+def random_walk_support_point(op, rv, init_dist, innovation_dist, steps):
     # shape = (1, B, S)
-    init_moment = moment(init_dist)
+    init_support_point = support_point(init_dist)
     # shape = (T-1, B, S)
-    innovation_moment = moment(innovation_dist)
+    innovation_support_point = support_point(innovation_dist)
     # shape = (T, B, S)
-    grw_moment = pt.concatenate([init_moment, innovation_moment], axis=0)
-    grw_moment = pt.cumsum(grw_moment, axis=0)
+    grw_support_point = pt.concatenate([init_support_point, innovation_support_point], axis=0)
+    grw_support_point = pt.cumsum(grw_support_point, axis=0)
     # shape = (B, T, S)
-    grw_moment = pt.moveaxis(grw_moment, 0, -op.ndim_supp)
-    return grw_moment
+    grw_support_point = pt.moveaxis(grw_support_point, 0, -op.ndim_supp)
+    return grw_support_point
 
 
 @_logprob.register(RandomWalkRV)
@@ -417,6 +422,8 @@ class MvStudentTRandomWalk(PredefinedRandomWalk):
 class AutoRegressiveRV(SymbolicRandomVariable):
     """A placeholder used to specify a log-likelihood for an AR sub-graph."""
 
+    signature = "(o),(),(o),(s)->(),(t)"
+    ndim_supp = 1
     default_output = 1
     ar_order: int
     constant_term: bool
@@ -495,7 +502,7 @@ class AR(Distribution):
     rv_type = AutoRegressiveRV
 
     def __new__(cls, name, rho, *args, steps=None, constant=False, ar_order=None, **kwargs):
-        rhos = pt.atleast_1d(pt.as_tensor_variable(floatX(rho)))
+        rhos = pt.atleast_1d(pt.as_tensor_variable(rho))
         ar_order = cls._get_ar_order(rhos=rhos, constant=constant, ar_order=ar_order)
         steps = get_support_shape_1d(
             support_shape=steps,
@@ -522,8 +529,8 @@ class AR(Distribution):
         **kwargs,
     ):
         _, sigma = get_tau_sigma(tau=tau, sigma=sigma)
-        sigma = pt.as_tensor_variable(floatX(sigma))
-        rhos = pt.atleast_1d(pt.as_tensor_variable(floatX(rho)))
+        sigma = pt.as_tensor_variable(sigma)
+        rhos = pt.atleast_1d(pt.as_tensor_variable(rho))
 
         if "init" in kwargs:
             warnings.warn(
@@ -655,7 +662,6 @@ class AR(Distribution):
             outputs=[noise_next_rng, ar_],
             ar_order=ar_order,
             constant_term=constant_term,
-            ndim_supp=1,
         )
 
         ar = ar_op(rhos, sigma, init_dist, steps)
@@ -709,16 +715,18 @@ def ar_logp(op, values, rhos, sigma, init_dist, steps, noise_rng, **kwargs):
     return init_logp + innov_logp
 
 
-@_moment.register(AutoRegressiveRV)
-def ar_moment(op, rv, rhos, sigma, init_dist, steps, noise_rng):
-    # Use last entry of init_dist moment as the moment for the whole AR
-    return pt.full_like(rv, moment(init_dist)[..., -1, None])
+@_support_point.register(AutoRegressiveRV)
+def ar_support_point(op, rv, rhos, sigma, init_dist, steps, noise_rng):
+    # Use last entry of init_dist support_point as the moment for the whole AR
+    return pt.full_like(rv, support_point(init_dist)[..., -1, None])
 
 
 class GARCH11RV(SymbolicRandomVariable):
     """A placeholder used to specify a GARCH11 graph."""
 
     default_output = 1
+    signature = "(),(),(),(),(),(s)->(),(t)"
+    ndim_supp = 1
     _print_name = ("GARCH11", "\\operatorname{GARCH11}")
 
     def update(self, node: Node):
@@ -819,13 +827,12 @@ class GARCH11(Distribution):
         (noise_next_rng,) = tuple(innov_updates_.values())
 
         garch11_ = pt.concatenate([init_[None, ...], y_t], axis=0).dimshuffle(
-            tuple(range(1, y_t.ndim)) + (0,)
+            (*range(1, y_t.ndim), 0)
         )
 
         garch11_op = GARCH11RV(
             inputs=[omega_, alpha_1_, beta_1_, initial_vol_, init_, steps_],
             outputs=[noise_next_rng, garch11_],
-            ndim_supp=1,
         )
 
         garch11 = garch11_op(omega, alpha_1, beta_1, initial_vol, init_dist, steps)
@@ -850,7 +857,7 @@ def garch11_logp(
 ):
     (value,) = values
     # Move the time axis to the first dimension
-    value_dimswapped = value.dimshuffle((value.ndim - 1,) + tuple(range(0, value.ndim - 1)))
+    value_dimswapped = value.dimshuffle((value.ndim - 1, *range(0, value.ndim - 1)))
     initial_vol = initial_vol * pt.ones_like(value_dimswapped[0])
 
     def volatility_update(x, vol, w, a, b):
@@ -869,8 +876,8 @@ def garch11_logp(
     return innov_logp
 
 
-@_moment.register(GARCH11RV)
-def garch11_moment(op, rv, omega, alpha_1, beta_1, initial_vol, init_dist, steps, noise_rng):
+@_support_point.register(GARCH11RV)
+def garch11_support_point(op, rv, omega, alpha_1, beta_1, initial_vol, init_dist, steps, noise_rng):
     # GARCH(1,1) mean is zero
     return pt.zeros_like(rv)
 
@@ -881,6 +888,7 @@ class EulerMaruyamaRV(SymbolicRandomVariable):
     default_output = 1
     dt: float
     sde_fn: Callable
+    ndim_supp = 1
     _print_name = ("EulerMaruyama", "\\operatorname{EulerMaruyama}")
 
     def __init__(self, *args, dt, sde_fn, **kwargs):
@@ -916,7 +924,7 @@ class EulerMaruyama(Distribution):
     rv_type = EulerMaruyamaRV
 
     def __new__(cls, name, dt, sde_fn, *args, steps=None, **kwargs):
-        dt = pt.as_tensor_variable(floatX(dt))
+        dt = pt.as_tensor_variable(dt)
         steps = get_support_shape_1d(
             support_shape=steps,
             shape=None,  # Shape will be checked in `cls.dist`
@@ -935,7 +943,7 @@ class EulerMaruyama(Distribution):
             raise ValueError("Must specify steps or shape parameter")
         steps = pt.as_tensor_variable(intX(steps), ndim=0)
 
-        dt = pt.as_tensor_variable(floatX(dt))
+        dt = pt.as_tensor_variable(dt)
         sde_pars = [pt.as_tensor_variable(x) for x in sde_pars]
 
         if init_dist is not None:
@@ -991,22 +999,22 @@ class EulerMaruyama(Distribution):
         y_t, innov_updates_ = pytensor.scan(
             fn=step,
             outputs_info=[init_],
-            non_sequences=sde_pars_ + [noise_rng],
+            non_sequences=[*sde_pars_, noise_rng],
             n_steps=steps_,
             strict=True,
         )
         (noise_next_rng,) = tuple(innov_updates_.values())
 
         sde_out_ = pt.concatenate([init_[None, ...], y_t], axis=0).dimshuffle(
-            tuple(range(1, y_t.ndim)) + (0,)
+            (*range(1, y_t.ndim), 0)
         )
 
         eulermaruyama_op = EulerMaruyamaRV(
-            inputs=[init_, steps_] + sde_pars_,
+            inputs=[init_, steps_, *sde_pars_],
             outputs=[noise_next_rng, sde_out_],
             dt=dt,
             sde_fn=sde_fn,
-            ndim_supp=1,
+            signature=f"(),(s),{','.join('()' for _ in sde_pars_)}->(),(t)",
         )
 
         eulermaruyama = eulermaruyama_op(init_dist, steps, *sde_pars)
