@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -31,8 +31,8 @@ from pymc.distributions.dist_math import check_parameters
 from pymc.distributions.distribution import (
     Distribution,
     SymbolicRandomVariable,
-    _moment,
-    moment,
+    _support_point,
+    support_point,
 )
 from pymc.distributions.shape_utils import _change_dist_size, change_dist_size, to_tuple
 from pymc.distributions.transforms import _default_transform
@@ -247,7 +247,7 @@ class Truncated(Distribution):
         return TruncatedRV(
             base_rv_op=dist.owner.op,
             inputs=graph_inputs_,
-            outputs=[tuple(updates.values())[0], truncated_rv_],
+            outputs=[next(iter(updates.values())), truncated_rv_],
             ndim_supp=0,
             max_n_steps=max_n_steps,
         )(*graph_inputs)
@@ -270,15 +270,15 @@ def change_truncated_size(op, dist, new_size, expand):
     )
 
 
-@_moment.register(TruncatedRV)
-def truncated_moment(op, rv, *inputs):
+@_support_point.register(TruncatedRV)
+def truncated_support_point(op, rv, *inputs):
     *rv_inputs, lower, upper, rng = inputs
 
-    # recreate untruncated rv and respective moment
+    # recreate untruncated rv and respective support_point
     untruncated_rv = op.base_rv_op.make_node(rng, *rv_inputs).default_output()
-    untruncated_moment = moment(untruncated_rv)
+    untruncated_support_point = support_point(untruncated_rv)
 
-    fallback_moment = pt.switch(
+    fallback_support_point = pt.switch(
         pt.and_(pt.bitwise_not(pt.isinf(lower)), pt.bitwise_not(pt.isinf(upper))),
         (upper - lower) / 2,  # lower and upper are finite
         pt.switch(
@@ -289,9 +289,9 @@ def truncated_moment(op, rv, *inputs):
     )
 
     return pt.switch(
-        pt.and_(pt.ge(untruncated_moment, lower), pt.le(untruncated_moment, upper)),
-        untruncated_moment,  # untruncated moment is between lower and upper
-        fallback_moment,
+        pt.and_(pt.ge(untruncated_support_point, lower), pt.le(untruncated_support_point, upper)),
+        untruncated_support_point,  # untruncated support_point is between lower and upper
+        fallback_support_point,
     )
 
 
