@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -15,8 +15,9 @@
 import numbers
 import warnings
 
+from collections.abc import Sequence
 from types import ModuleType
-from typing import Optional, Sequence, Union
+from typing import Optional, Union
 
 import numpy as np
 import pytensor.tensor as pt
@@ -91,7 +92,7 @@ class HSGP(Base):
 
     The `gp.HSGP` class is an implementation of the Hilbert Space Gaussian process.  It is a
     reduced rank GP approximation that uses a fixed set of basis vectors whose coefficients are
-    random functions of a stationary covariance function's power spectral density.  It's usage
+    random functions of a stationary covariance function's power spectral density.  Its usage
     is largely similar to `gp.Latent`.  Like `gp.Latent`, it does not assume a Gaussian noise model
     and can be used with any likelihood, or as a component anywhere within a model.  Also like
     `gp.Latent`, it has `prior` and `conditional` methods.  It supports any sum of covariance
@@ -99,7 +100,7 @@ class HSGP(Base):
     `Periodic` covariance function, which uses a different set of basis functions for a
     low rank approximation, as described in `HSGPPeriodic`.).
 
-    For information on choosing appropriate `m`, `L`, and `c`, refer Ruitort-Mayol et al. or to
+    For information on choosing appropriate `m`, `L`, and `c`, refer to Ruitort-Mayol et al. or to
     the PyMC examples that use HSGP.
 
     To work with the HSGP in its "linearized" form, as a matrix of basis vectors and a vector of
@@ -116,14 +117,14 @@ class HSGP(Base):
         `active_dim`.
     c: float
         The proportion extension factor.  Used to construct L from X.  Defined as `S = max|X|` such
-        that `X` is in `[-S, S]`.  `L` is the calculated as `c * S`.  One of `c` or `L` must be
+        that `X` is in `[-S, S]`.  `L` is calculated as `c * S`.  One of `c` or `L` must be
         provided.  Further information can be found in Ruitort-Mayol et al.
     drop_first: bool
         Default `False`. Sometimes the first basis vector is quite "flat" and very similar to
         the intercept term.  When there is an intercept in the model, ignoring the first basis
         vector may improve sampling. This argument will be deprecated in future versions.
     parameterization: str
-        Whether to use `centred` or `noncentered` parameterization when multiplying the
+        Whether to use the `centered` or `noncentered` parameterization when multiplying the
         basis by the coefficients.
     cov_func: Covariance function, must be an instance of `Stationary` and implement a
         `power_spectral_density` method.
@@ -244,16 +245,16 @@ class HSGP(Base):
         """Linearized version of the HSGP.  Returns the Laplace eigenfunctions and the square root
         of the power spectral density needed to create the GP.
 
-        This function allows the user to bypass the GP interface and work directly with the basis
+        This function allows the user to bypass the GP interface and work with the basis
         and coefficients directly.  This format allows the user to create predictions using
         `pm.set_data` similarly to a linear model.  It also enables computational speed ups in
-        multi-GP models since they may share the same basis.  The return values are the Laplace
+        multi-GP models, since they may share the same basis.  The return values are the Laplace
         eigenfunctions `phi`, and the square root of the power spectral density.
 
         Correct results when using `prior_linearized` in tandem with `pm.set_data` and
         `pm.MutableData` require two conditions.  First, one must specify `L` instead of `c` when
         the GP is constructed.  If not, a RuntimeError is raised.  Second, the `Xs` needs to be
-        zero-centered, so it's mean must be subtracted.  An example is given below.
+        zero-centered, so its mean must be subtracted.  An example is given below.
 
         Parameters
         ----------
@@ -285,9 +286,9 @@ class HSGP(Base):
                 # L = [10] means the approximation is valid from Xs = [-10, 10]
                 gp = pm.gp.HSGP(m=[200], L=[10], cov_func=cov_func)
 
-                # Order is important.  First calculate the mean, then make X a shared variable,
-                # then subtract the mean.  When X is mutated later, the correct mean will be
-                # subtracted.
+                # Order is important.
+                # First calculate the mean, then make X a shared variable, then subtract the mean.
+                #  When X is mutated later, the correct mean will be subtracted.
                 X_mean = np.mean(X, axis=0)
                 X = pm.MutableData("X", X)
                 Xs = X - X_mean
@@ -300,9 +301,14 @@ class HSGP(Base):
                 # as m_star.
                 beta = pm.Normal("beta", size=gp._m_star)
 
-                # The (non-centered) GP approximation is given by
+                # The (non-centered) GP approximation is given by:
                 f = pm.Deterministic("f", phi @ (beta * sqrt_psd))
 
+                # The centered approximation can be more efficient when
+                # the GP is stronger than the noise
+                # beta = pm.Normal("beta", sigma=sqrt_psd, size=gp._m_star)
+                # f = pm.Deterministic("f", phi @ beta)
+
                 ...
 
 
@@ -332,7 +338,7 @@ class HSGP(Base):
         omega = pt.sqrt(eigvals)
         psd = self.cov_func.power_spectral_density(omega)
 
-        i = int(self._drop_first == True)
+        i = int(self._drop_first is True)
         return phi[:, i:], pt.sqrt(psd[i:])
 
     def prior(self, name: str, X: TensorLike, dims: Optional[str] = None):  # type: ignore
@@ -382,7 +388,7 @@ class HSGP(Base):
 
         eigvals = calc_eigenvalues(self.L, self._m, tl=pt)
         phi = calc_eigenvectors(Xnew - X_mean, self.L, eigvals, self._m, tl=pt)
-        i = int(self._drop_first == True)
+        i = int(self._drop_first is True)
 
         if self._parameterization == "noncentered":
             return self.mean_func(Xnew) + phi[:, i:] @ (beta * sqrt_psd)
@@ -445,7 +451,7 @@ class HSGPPeriodic(Base):
 
         with pm.Model() as model:
             # Specify the covariance function, only for the 1-D case
-            scale = pm.HalfNormal(10)
+            scale = pm.HalfNormal("scale", 10)
             cov_func = pm.gp.cov.Periodic(1, period=1, ls=0.1)
 
             # Specify the approximation with 25 basis vectors
@@ -534,8 +540,8 @@ class HSGPPeriodic(Base):
             X = np.linspace(0, 10, 100)[:, None]
 
             with pm.Model() as model:
-                scale = pm.HalfNormal(10)
-                cov_func = pm.gp.cov.Periodic(1, period=1, ls=ell)
+                scale = pm.HalfNormal("scale", 10)
+                cov_func = pm.gp.cov.Periodic(1, period=1.0, ls=2.0)
 
                 # m=200 means 200 basis vectors
                 gp = pm.gp.HSGPPeriodic(m=200, scale=scale, cov_func=cov_func)
