@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -20,18 +20,11 @@ import sys
 import time
 import warnings
 
+from collections.abc import Iterator, Mapping, Sequence
 from typing import (
     Any,
-    Dict,
-    Iterator,
-    List,
     Literal,
-    Mapping,
     Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Type,
     Union,
     overload,
 )
@@ -100,10 +93,10 @@ _log = logging.getLogger(__name__)
 
 def instantiate_steppers(
     model: Model,
-    steps: List[Step],
-    selected_steps: Mapping[Type[BlockedStep], List[Any]],
-    step_kwargs: Optional[Dict[str, Dict]] = None,
-) -> Union[Step, List[Step]]:
+    steps: list[Step],
+    selected_steps: Mapping[type[BlockedStep], list[Any]],
+    step_kwargs: Optional[dict[str, dict]] = None,
+) -> Union[Step, list[Step]]:
     """Instantiate steppers assigned to the model variables.
 
     This function is intended to be called automatically from ``sample()``, but
@@ -161,9 +154,9 @@ def instantiate_steppers(
 def assign_step_methods(
     model: Model,
     step: Optional[Union[Step, Sequence[Step]]] = None,
-    methods: Optional[Sequence[Type[BlockedStep]]] = None,
-    step_kwargs: Optional[Dict[str, Any]] = None,
-) -> Union[Step, List[Step]]:
+    methods: Optional[Sequence[type[BlockedStep]]] = None,
+    step_kwargs: Optional[dict[str, Any]] = None,
+) -> Union[Step, list[Step]]:
     """Assign model variables to appropriate step methods.
 
     Passing a specified model will auto-assign its constituent stochastic
@@ -193,8 +186,8 @@ def assign_step_methods(
     methods : list
         List of step methods associated with the model's variables.
     """
-    steps: List[Step] = []
-    assigned_vars: Set[Variable] = set()
+    steps: list[Step] = []
+    assigned_vars: set[Variable] = set()
 
     if step is not None:
         if isinstance(step, (BlockedStep, CompoundStep)):
@@ -212,8 +205,8 @@ def assign_step_methods(
 
     # Use competence classmethods to select step methods for remaining
     # variables
-    methods_list: List[Type[BlockedStep]] = list(methods or pm.STEP_METHODS)
-    selected_steps: Dict[Type[BlockedStep], List] = {}
+    methods_list: list[type[BlockedStep]] = list(methods or pm.STEP_METHODS)
+    selected_steps: dict[type[BlockedStep], list] = {}
     model_logp = model.logp()
 
     for var in model.value_vars:
@@ -263,7 +256,7 @@ def all_continuous(vars):
 
 
 def _sample_external_nuts(
-    sampler: str,
+    sampler: Literal["nutpie", "numpyro", "blackjax"],
     draws: int,
     tune: int,
     chains: int,
@@ -272,8 +265,8 @@ def _sample_external_nuts(
     initvals: Union[StartDict, Sequence[Optional[StartDict]], None],
     model: Model,
     progressbar: bool,
-    idata_kwargs: Optional[Dict],
-    nuts_sampler_kwargs: Optional[Dict],
+    idata_kwargs: Optional[dict],
+    nuts_sampler_kwargs: Optional[dict],
     **kwargs,
 ):
     if nuts_sampler_kwargs is None:
@@ -344,10 +337,10 @@ def _sample_external_nuts(
         )
         return idata
 
-    elif sampler == "numpyro":
+    elif sampler in ("numpyro", "blackjax"):
         import pymc.sampling.jax as pymc_jax
 
-        idata = pymc_jax.sample_numpyro_nuts(
+        idata = pymc_jax.sample_jax_nuts(
             draws=draws,
             tune=tune,
             chains=chains,
@@ -356,23 +349,7 @@ def _sample_external_nuts(
             initvals=initvals,
             model=model,
             progressbar=progressbar,
-            idata_kwargs=idata_kwargs,
-            **nuts_sampler_kwargs,
-        )
-        return idata
-
-    elif sampler == "blackjax":
-        import pymc.sampling.jax as pymc_jax
-
-        idata = pymc_jax.sample_blackjax_nuts(
-            draws=draws,
-            tune=tune,
-            chains=chains,
-            target_accept=target_accept,
-            random_seed=random_seed,
-            initvals=initvals,
-            model=model,
-            progress_bar=progressbar,
+            nuts_sampler=sampler,
             idata_kwargs=idata_kwargs,
             **nuts_sampler_kwargs,
         )
@@ -394,7 +371,7 @@ def sample(
     random_seed: RandomState = None,
     progressbar: bool = True,
     step=None,
-    nuts_sampler: str = "pymc",
+    nuts_sampler: Literal["pymc", "nutpie", "numpyro", "blackjax"] = "pymc",
     initvals: Optional[Union[StartDict, Sequence[Optional[StartDict]]]] = None,
     init: str = "auto",
     jitter_max_retries: int = 10,
@@ -404,13 +381,12 @@ def sample(
     compute_convergence_checks: bool = True,
     keep_warning_stat: bool = False,
     return_inferencedata: Literal[True] = True,
-    idata_kwargs: Optional[Dict[str, Any]] = None,
-    nuts_sampler_kwargs: Optional[Dict[str, Any]] = None,
+    idata_kwargs: Optional[dict[str, Any]] = None,
+    nuts_sampler_kwargs: Optional[dict[str, Any]] = None,
     callback=None,
     mp_ctx=None,
     **kwargs,
-) -> InferenceData:
-    ...
+) -> InferenceData: ...
 
 
 @overload
@@ -423,7 +399,7 @@ def sample(
     random_seed: RandomState = None,
     progressbar: bool = True,
     step=None,
-    nuts_sampler: str = "pymc",
+    nuts_sampler: Literal["pymc", "nutpie", "numpyro", "blackjax"] = "pymc",
     initvals: Optional[Union[StartDict, Sequence[Optional[StartDict]]]] = None,
     init: str = "auto",
     jitter_max_retries: int = 10,
@@ -433,14 +409,13 @@ def sample(
     compute_convergence_checks: bool = True,
     keep_warning_stat: bool = False,
     return_inferencedata: Literal[False],
-    idata_kwargs: Optional[Dict[str, Any]] = None,
-    nuts_sampler_kwargs: Optional[Dict[str, Any]] = None,
+    idata_kwargs: Optional[dict[str, Any]] = None,
+    nuts_sampler_kwargs: Optional[dict[str, Any]] = None,
     callback=None,
     mp_ctx=None,
     model: Optional[Model] = None,
     **kwargs,
-) -> MultiTrace:
-    ...
+) -> MultiTrace: ...
 
 
 def sample(
@@ -452,7 +427,7 @@ def sample(
     random_seed: RandomState = None,
     progressbar: bool = True,
     step=None,
-    nuts_sampler: str = "pymc",
+    nuts_sampler: Literal["pymc", "nutpie", "numpyro", "blackjax"] = "pymc",
     initvals: Optional[Union[StartDict, Sequence[Optional[StartDict]]]] = None,
     init: str = "auto",
     jitter_max_retries: int = 10,
@@ -462,8 +437,8 @@ def sample(
     compute_convergence_checks: bool = True,
     keep_warning_stat: bool = False,
     return_inferencedata: bool = True,
-    idata_kwargs: Optional[Dict[str, Any]] = None,
-    nuts_sampler_kwargs: Optional[Dict[str, Any]] = None,
+    idata_kwargs: Optional[dict[str, Any]] = None,
+    nuts_sampler_kwargs: Optional[dict[str, Any]] = None,
     callback=None,
     mp_ctx=None,
     model: Optional[Model] = None,
@@ -672,8 +647,11 @@ def sample(
     if draws == 0:
         msg = "Tuning was enabled throughout the whole trace."
         _log.warning(msg)
-    elif draws < 500:
-        msg = "Only %s samples in chain." % draws
+    elif draws < 100:
+        msg = (
+            "Only %s samples per chain. Reliable r-hat and ESS diagnostics require longer chains for accurate estimate."
+            % draws
+        )
         _log.warning(msg)
 
     auto_nuts_init = True
@@ -739,7 +717,7 @@ def sample(
         initial_points = [ipfn(seed) for ipfn, seed in zip(ipfns, random_seed_list)]
 
     # One final check that shapes and logps at the starting points are okay.
-    ip: Dict[str, np.ndarray]
+    ip: dict[str, np.ndarray]
     for ip in initial_points:
         model.check_start_vals(ip)
         _check_start_shape(model, ip)
@@ -848,7 +826,7 @@ def _sample_return(
     compute_convergence_checks: bool,
     return_inferencedata: bool,
     keep_warning_stat: bool,
-    idata_kwargs: Dict[str, Any],
+    idata_kwargs: dict[str, Any],
     model: Model,
 ) -> Union[InferenceData, MultiTrace]:
     """Final step of `pm.sampler` that picks/slices chains,
@@ -890,7 +868,7 @@ def _sample_return(
 
     idata = None
     if compute_convergence_checks or return_inferencedata:
-        ikwargs: Dict[str, Any] = dict(model=model, save_warmup=not discard_tuned_samples)
+        ikwargs: dict[str, Any] = dict(model=model, save_warmup=not discard_tuned_samples)
         ikwargs.update(idata_kwargs)
         idata = pm.to_inference_data(mtrace, **ikwargs)
 
@@ -1104,7 +1082,7 @@ def _iter_sample(
             point, stats = step.step(point)
             trace.record(point, stats)
             log_warning_stats(stats)
-            diverging = i > tune and len(stats) > 0 and (stats[0].get("diverging") == True)
+            diverging = i > tune and len(stats) > 0 and (stats[0].get("diverging") is True)
             if callback is not None:
                 callback(
                     trace=trace,
@@ -1216,7 +1194,7 @@ def _init_jitter(
     seeds: Union[Sequence[int], np.ndarray],
     jitter: bool,
     jitter_max_retries: int,
-) -> List[PointType]:
+) -> list[PointType]:
     """Apply a uniform jitter in [-1, 1] to the test value as starting point in each chain.
 
     ``model.check_start_vals`` is used to test whether the jittered starting
@@ -1276,7 +1254,7 @@ def init_nuts(
     tune: Optional[int] = None,
     initvals: Optional[Union[StartDict, Sequence[Optional[StartDict]]]] = None,
     **kwargs,
-) -> Tuple[Sequence[PointType], NUTS]:
+) -> tuple[Sequence[PointType], NUTS]:
     """Set up the mass matrix initialization for NUTS.
 
     NUTS convergence and sampling speed is extremely dependent on the
