@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -17,8 +17,9 @@
 import logging
 import warnings
 
+from collections.abc import Iterator, Sequence
 from copy import copy
-from typing import Iterator, List, Sequence, Tuple, Union
+from typing import Union
 
 import cloudpickle
 import numpy as np
@@ -128,14 +129,12 @@ def warn_population_size(
     if has_demcmc and chains < 3:
         raise ValueError(
             "DEMetropolis requires at least 3 chains. "
-            "For this {}-dimensional model you should use ≥{} chains".format(
-                initial_point_model_size, initial_point_model_size + 1
-            )
+            f"For this {initial_point_model_size}-dimensional model you should use ≥{initial_point_model_size + 1} chains"
         )
     if has_demcmc and chains <= initial_point_model_size:
         warnings.warn(
             "DEMetropolis should be used with more chains than dimensions! "
-            "(The model has {} dimensions.)".format(initial_point_model_size),
+            f"(The model has {initial_point_model_size} dimensions.)",
             UserWarning,
             stacklevel=2,
         )
@@ -265,7 +264,7 @@ class PopulationStepper:
             _log.exception(f"ChainWalker{c}")
         return
 
-    def step(self, tune_stop: bool, population) -> List[Tuple[PointType, StatsType]]:
+    def step(self, tune_stop: bool, population) -> list[tuple[PointType, StatsType]]:
         """Step the entire population of chains.
 
         Parameters
@@ -280,7 +279,7 @@ class PopulationStepper:
         update : list
             List of (Point, stats) tuples for all chains
         """
-        updates: List[Tuple[PointType, StatsType]] = []
+        updates: list[tuple[PointType, StatsType]] = []
         if self.is_parallelized:
             for c in range(self.nchains):
                 self._primary_ends[c].send((tune_stop, population))
@@ -351,7 +350,7 @@ def _prepare_iter_population(
     population = [start[c] for c in range(nchains)]
 
     # 2. Set up the steppers
-    steppers: List[Step] = []
+    steppers: list[Step] = []
     for c in range(nchains):
         # need independent samplers for each chain
         # it is important to copy the actual steppers (but not the delta_logp)
