@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -19,13 +19,13 @@ import warnings
 
 from collections import defaultdict
 from itertools import repeat
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Optional, Union
 
 import cloudpickle
 import numpy as np
 
 from arviz import InferenceData
-from fastprogress.fastprogress import progress_bar
+from fastprogress.fastprogress import force_console_behavior, progress_bar
 
 import pymc
 
@@ -259,7 +259,7 @@ def _save_sample_stats(
     _t_sampling,
     idata_kwargs,
     model: Model,
-) -> Tuple[Optional[Any], Optional[InferenceData]]:
+) -> tuple[Optional[Any], Optional[InferenceData]]:
     sample_settings_dict = sample_settings[0]
     sample_settings_dict["_t_sampling"] = _t_sampling
     sample_stats_dict = sample_stats[0]
@@ -294,7 +294,7 @@ def _save_sample_stats(
             library=pymc,
         )
 
-        ikwargs: Dict[str, Any] = dict(model=model)
+        ikwargs: dict[str, Any] = dict(model=model)
         if idata_kwargs is not None:
             ikwargs.update(idata_kwargs)
         idata = to_inference_data(trace, **ikwargs)
@@ -314,7 +314,7 @@ def _sample_smc_int(
     **kernel_kwargs,
 ):
     """Run one SMC instance."""
-    in_out_pickled = type(model) == bytes
+    in_out_pickled = isinstance(model, bytes)
     if in_out_pickled:
         # function was called in multiprocessing context, deserialize first
         (draws, kernel, start, model) = map(
@@ -376,6 +376,8 @@ def _sample_smc_int(
 
 
 def run_chains_parallel(chains, progressbar, to_run, params, random_seed, kernel_kwargs, cores):
+    # fastprogress HTML progress bar does not support multiprocessing
+    _, progress_bar = force_console_behavior()
     pbar = progress_bar((), total=100, display=progressbar)
     pbar.update(0)
     pbars = [pbar] + [None] * (chains - 1)
