@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -100,7 +100,7 @@ def adjust_precision(tau, scaling_bound=1e-8):
     return exp(bounded) ** 2
 
 
-def bound(a, l, u):
+def bound(a, l, u):  # noqa E741
     return np.maximum(np.minimum(a, u), l)
 
 
