@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -15,7 +15,8 @@
 import functools
 import warnings
 
-from typing import Any, Dict, List, NewType, Optional, Sequence, Tuple, Union, cast
+from collections.abc import Sequence
+from typing import Any, NewType, Optional, Union, cast
 
 import arviz
 import cloudpickle
@@ -239,25 +240,26 @@ def biwrap(wrapper):
 
 
 def dataset_to_point_list(
-    ds: xarray.Dataset, sample_dims: Sequence[str]
-) -> Tuple[List[Dict[str, np.ndarray]], Dict[str, Any]]:
+    ds: Union[xarray.Dataset, dict[str, xarray.DataArray]], sample_dims: Sequence[str]
+) -> tuple[list[dict[str, np.ndarray]], dict[str, Any]]:
     # All keys of the dataset must be a str
-    var_names = list(ds.keys())
+    var_names = cast(list[str], list(ds.keys()))
     for vn in var_names:
         if not isinstance(vn, str):
             raise ValueError(f"Variable names must be str, but dataset key {vn} is a {type(vn)}.")
     num_sample_dims = len(sample_dims)
-    stacked_dims = {dim_name: ds[dim_name] for dim_name in sample_dims}
-    ds = ds.transpose(*sample_dims, ...)
+    stacked_dims = {dim_name: ds[var_names[0]][dim_name] for dim_name in sample_dims}
+    transposed_dict = {vn: da.transpose(*sample_dims, ...) for vn, da in ds.items()}
     stacked_dict = {
-        vn: da.values.reshape((-1, *da.shape[num_sample_dims:])) for vn, da in ds.items()
+        vn: da.values.reshape((-1, *da.shape[num_sample_dims:]))
+        for vn, da in transposed_dict.items()
     }
     points = [
         {vn: stacked_dict[vn][i, ...] for vn in var_names}
         for i in range(np.prod([len(coords) for coords in stacked_dims.values()]))
     ]
     # use the list of points
-    return cast(List[Dict[str, np.ndarray]], points), stacked_dims
+    return cast(list[dict[str, np.ndarray]], points), stacked_dims
 
 
 def drop_warning_stat(idata: arviz.InferenceData) -> arviz.InferenceData:
@@ -274,7 +276,7 @@ def drop_warning_stat(idata: arviz.InferenceData) -> arviz.InferenceData:
     return nidata
 
 
-def chains_and_samples(data: Union[xarray.Dataset, arviz.InferenceData]) -> Tuple[int, int]:
+def chains_and_samples(data: Union[xarray.Dataset, arviz.InferenceData]) -> tuple[int, int]:
     """Extract and return number of chains and samples in xarray or arviz traces."""
     dataset: xarray.Dataset
     if isinstance(data, xarray.Dataset):
@@ -451,7 +453,7 @@ def _get_seeds_per_chain(
 
 def get_value_vars_from_user_vars(
     vars: Union[Variable, Sequence[Variable]], model
-) -> List[Variable]:
+) -> list[Variable]:
     """Converts user "vars" input into value variables.
 
     More often than not, users will pass random variables, and we will extract the
