@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -458,8 +458,8 @@ class Operator:
         self.approx = approx
         if self.require_logq and not approx.has_logq:
             raise ExplicitInferenceError(
-                "%s requires logq, but %s does not implement it"
-                "please change inference method" % (self, approx)
+                f"{self} requires logq, but {approx} does not implement it"
+                "please change inference method"
             )
 
     inputs = property(lambda self: self.approx.inputs)
@@ -510,9 +510,7 @@ class Operator:
         return self.objective_class(self, f)
 
     def __str__(self):  # pragma: no cover
-        return "%(op)s[%(ap)s]" % dict(
-            op=self.__class__.__name__, ap=self.approx.__class__.__name__
-        )
+        return f"{self.__class__.__name__}[{self.approx.__class__.__name__}]"
 
 
 def collect_shared_to_list(params):
@@ -663,6 +661,7 @@ class Group(WithMemoization):
     -   Kingma, D. P., & Welling, M. (2014).
         `Auto-Encoding Variational Bayes. stat, 1050, 1. <https://arxiv.org/abs/1312.6114>`_
     """
+
     # needs to be defined in init
     shared_params = None
     symbolic_initial = None
@@ -700,8 +699,8 @@ class Group(WithMemoization):
     def group_for_params(cls, params):
         if frozenset(params) not in cls.__param_registry:
             raise KeyError(
-                "No such group for the following params: {!r}, "
-                "only the following are supported\n\n{}".format(params, cls.__param_registry)
+                f"No such group for the following params: {params!r}, "
+                f"only the following are supported\n\n{cls.__param_registry}"
             )
         return cls.__param_registry[frozenset(params)]
 
@@ -709,8 +708,8 @@ class Group(WithMemoization):
     def group_for_short_name(cls, name):
         if name.lower() not in cls.__name_registry:
             raise KeyError(
-                "No such group: {!r}, "
-                "only the following are supported\n\n{}".format(name, cls.__name_registry)
+                f"No such group: {name!r}, "
+                f"only the following are supported\n\n{cls.__name_registry}"
             )
         return cls.__name_registry[name.lower()]
 
@@ -799,9 +798,7 @@ class Group(WithMemoization):
         if givens != needed:
             raise ParametrizationError(
                 "Passed parameters do not have a needed set of keys, "
-                "they should be equal, got {givens}, needed {needed}".format(
-                    givens=givens, needed=needed
-                )
+                f"they should be equal, got {givens}, needed {needed}"
             )
         self._user_params = dict()
         spec = self.get_param_spec_for(d=self.ddim, **kwargs.pop("spec_kw", {}))
@@ -817,6 +814,7 @@ class Group(WithMemoization):
         ----------
         name: str
             name for tensor
+
         Returns
         -------
         tensor
@@ -830,6 +828,7 @@ class Group(WithMemoization):
         ----------
         name: str
             name for tensor
+
         Returns
         -------
         tensor
@@ -983,14 +982,12 @@ class Group(WithMemoization):
     @overload
     def set_size_and_deterministic(
         self, node: Variable, s, d: bool, more_replacements: dict | None = None
-    ) -> Variable:
-        ...
+    ) -> Variable: ...
 
     @overload
     def set_size_and_deterministic(
         self, node: list[Variable], s, d: bool, more_replacements: dict | None = None
-    ) -> list[Variable]:
-        ...
+    ) -> list[Variable]: ...
 
     @pytensor.config.change_flags(compute_test_value="off")
     def set_size_and_deterministic(
@@ -1511,7 +1508,7 @@ class Approximation(WithMemoization):
         ):
             if name in vars_names(vars_):
                 name_, slc, shape, dtype = ordering[name]
-                found = random[..., slc].reshape((random.shape[0],) + shape).astype(dtype)
+                found = random[..., slc].reshape((random.shape[0], *shape)).astype(dtype)
                 found.name = name + "_vi_random_slice"
                 break
         else:
@@ -1615,4 +1612,4 @@ class Approximation(WithMemoization):
 
     @property
     def params(self):
-        return sum(self.collect("params"), [])
+        return list(itertools.chain.from_iterable(self.collect("params")))
