@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -11,11 +11,8 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-# pylint: disable=no-member, invalid-name, redefined-outer-name, protected-access, too-many-public-methods
 import warnings
 
-from typing import Dict, Tuple
-
 import numpy as np
 import pytensor.tensor as pt
 import pytest
@@ -106,7 +103,7 @@ class TestDataPyMC:
 
     def get_predictions_inference_data(
         self, data, eight_schools_params, inplace
-    ) -> Tuple[InferenceData, Dict[str, np.ndarray]]:
+    ) -> tuple[InferenceData, dict[str, np.ndarray]]:
         with data.model:
             prior = pm.sample_prior_predictive(return_inferencedata=False)
             posterior_predictive = pm.sample_posterior_predictive(
@@ -129,7 +126,7 @@ class TestDataPyMC:
 
     def make_predictions_inference_data(
         self, data, eight_schools_params
-    ) -> Tuple[InferenceData, Dict[str, np.ndarray]]:
+    ) -> tuple[InferenceData, dict[str, np.ndarray]]:
         with data.model:
             posterior_predictive = pm.sample_posterior_predictive(
                 data.obj, return_inferencedata=False
@@ -159,7 +156,7 @@ class TestDataPyMC:
         chains = inference_data.posterior.sizes["chain"]
         draws = inference_data.posterior.sizes["draw"]
         obs = inference_data.observed_data["obs"]
-        assert inference_data.log_likelihood["obs"].shape == (chains, draws) + obs.shape
+        assert inference_data.log_likelihood["obs"].shape == (chains, draws, *obs.shape)
 
     def test_predictions_to_idata(self, data, eight_schools_params):
         "Test that we can add predictions to a previously-existing InferenceData."
@@ -359,9 +356,7 @@ class TestDataPyMC:
         with model:
             mu = pm.Normal("mu", 0, 1, size=2)
             sd_dist = pm.HalfNormal.dist(1.0, size=2)
-            # pylint: disable=unpacking-non-sequence
             chol, *_ = pm.LKJCholeskyCov("chol_cov", n=2, eta=1, sd_dist=sd_dist)
-            # pylint: enable=unpacking-non-sequence
             with pytest.warns(ImputationWarning):
                 y = pm.MvNormal("y", mu=mu, chol=chol, observed=data)
             inference_data = pm.sample(
@@ -443,7 +438,7 @@ class TestDataPyMC:
             y = pm.MutableData("y", [1.0, 2.0, 3.0])
             beta_sigma = pm.MutableData("beta_sigma", 1)
             beta = pm.Normal("beta", 0, beta_sigma)
-            obs = pm.Normal("obs", x * beta, 1, observed=y)  # pylint: disable=unused-variable
+            obs = pm.Normal("obs", x * beta, 1, observed=y)
             trace = pm.sample(100, chains=2, tune=100, return_inferencedata=False)
             if use_context:
                 inference_data = to_inference_data(trace=trace, log_likelihood=True)
@@ -466,7 +461,7 @@ class TestDataPyMC:
             x = pm.ConstantData("x", [1.0, 2.0, 3.0])
             y = pm.MutableData("y", [1.0, 2.0, 3.0])
             beta = pm.Normal("beta", 0, 1)
-            obs = pm.Normal("obs", x * beta, 1, observed=y)  # pylint: disable=unused-variable
+            obs = pm.Normal("obs", x * beta, 1, observed=y)
             trace = pm.sample(100, tune=100, return_inferencedata=False)
             inference_data = to_inference_data(trace)
 
@@ -478,7 +473,7 @@ class TestDataPyMC:
             x = pm.MutableData("x", [1.0, 2.0])
             y = pm.ConstantData("y", [1.0, 2.0])
             beta = pm.Normal("beta", 0, 1)
-            obs = pm.Normal("obs", x * beta, 1, observed=y)  # pylint: disable=unused-variable
+            obs = pm.Normal("obs", x * beta, 1, observed=y)
             predictive_trace = pm.sample_posterior_predictive(
                 inference_data, return_inferencedata=False
             )
@@ -506,7 +501,7 @@ class TestDataPyMC:
             x = pm.ConstantData("x", [1.0, 2.0, 3.0])
             y = pm.MutableData("y", [1.0, 2.0, 3.0])
             beta = pm.Normal("beta", 0, 1)
-            obs = pm.Normal("obs", x * beta, 1, observed=y)  # pylint: disable=unused-variable
+            obs = pm.Normal("obs", x * beta, 1, observed=y)
             idata = pm.sample(100, tune=100)
             prior = pm.sample_prior_predictive(return_inferencedata=False)
             posterior_predictive = pm.sample_posterior_predictive(idata, return_inferencedata=False)
@@ -540,7 +535,7 @@ class TestDataPyMC:
             x = pm.MutableData("x", [1.0, 2.0, 3.0])
             y = pm.ConstantData("y", [1.0, 2.0, 3.0])
             beta = pm.Normal("beta", 0, 1)
-            obs = pm.Normal("obs", x * beta, 1, observed=y)  # pylint: disable=unused-variable
+            obs = pm.Normal("obs", x * beta, 1, observed=y)
             prior = pm.sample_prior_predictive(return_inferencedata=False)
 
         test_dict = {
