@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -13,7 +13,6 @@
 #   limitations under the License.
 
 import functools as ft
-import warnings
 
 import numpy as np
 import numpy.testing as npt
@@ -27,7 +26,7 @@ from pytensor.compile.mode import Mode
 
 import pymc as pm
 
-from pymc.distributions.continuous import Normal, Uniform, get_tau_sigma, interpolated
+from pymc.distributions.continuous import get_tau_sigma, interpolated
 from pymc.distributions.dist_math import clipped_beta_rvs
 from pymc.logprob.basic import icdf, logcdf, logp
 from pymc.logprob.utils import ParameterValueError
@@ -37,13 +36,12 @@ from pymc.testing import (
     Circ,
     Domain,
     R,
-    Rminusbig,
     Rplus,
     Rplusbig,
     Rplusunif,
     Runif,
     Unit,
-    assert_moment_is_expected,
+    assert_support_point_is_expected,
     check_icdf,
     check_logcdf,
     check_logp,
@@ -52,7 +50,6 @@ from pymc.testing import (
     seeded_scipy_distribution_builder,
     select_by_precision,
 )
-from tests.logprob.utils import create_pytensor_params, scipy_logprob_tester
 
 try:
     from polyagamma import polyagamma_cdf, polyagamma_pdf, random_polyagamma
@@ -417,9 +414,7 @@ class TestMatchesScipy:
     def test_kumaraswamy(self):
         # Scipy does not have a built-in Kumaraswamy
         def scipy_log_pdf(value, a, b):
-            return (
-                np.log(a) + np.log(b) + (a - 1) * np.log(value) + (b - 1) * np.log(1 - value**a)
-            )
+            return np.log(a) + np.log(b) + (a - 1) * np.log(value) + (b - 1) * np.log(1 - value**a)
 
         def scipy_log_cdf(value, a, b):
             return pm.math.log1mexp_numpy(b * np.log1p(-(value**a)), negative_input=True)
@@ -892,7 +887,6 @@ class TestMatchesScipy:
     def test_interpolated(self):
         for mu in R.vals:
             for sigma in Rplus.vals:
-                # pylint: disable=cell-var-from-loop
                 xmin = mu - 5 * sigma
                 xmax = mu + 5 * sigma
 
@@ -1003,26 +997,45 @@ class TestMatchesScipy:
         assert np.isinf(logp[2])
 
     def test_get_tau_sigma(self):
-        # Fail on warnings
-        with warnings.catch_warnings():
-            warnings.simplefilter("error")
+        sigma = np.array(2)
+        tau, _ = get_tau_sigma(sigma=sigma)
+        npt.assert_almost_equal(tau.eval(), 1.0 / sigma**2)
 
-            sigma = np.array(2)
-            npt.assert_almost_equal(get_tau_sigma(sigma=sigma), [1.0 / sigma**2, sigma])
+        tau = np.array(2)
+        _, sigma = get_tau_sigma(tau=tau)
+        npt.assert_almost_equal(sigma.eval(), tau**-0.5)
 
-            tau = np.array(2)
-            npt.assert_almost_equal(get_tau_sigma(tau=tau), [tau, tau**-0.5])
+        tau, _ = get_tau_sigma(sigma=pt.constant(-2))
+        npt.assert_almost_equal(tau.eval(), -0.25)
 
-            tau, _ = get_tau_sigma(sigma=pt.constant(-2))
-            npt.assert_almost_equal(tau.eval(), -0.25)
+        _, sigma = get_tau_sigma(tau=pt.constant(-2))
+        npt.assert_almost_equal(sigma.eval(), -1.0 / np.sqrt(2.0))
 
-            _, sigma = get_tau_sigma(tau=pt.constant(-2))
-            npt.assert_almost_equal(sigma.eval(), -np.sqrt(1 / 2))
+        sigma = [1, 2]
+        tau, _ = get_tau_sigma(sigma=sigma)
+        npt.assert_almost_equal(tau.eval(), 1.0 / np.array(sigma) ** 2)
 
-            sigma = [1, 2]
-            npt.assert_almost_equal(
-                get_tau_sigma(sigma=sigma), [1.0 / np.array(sigma) ** 2, np.array(sigma)]
-            )
+        # Test null arguments
+        tau, sigma = get_tau_sigma()
+        npt.assert_almost_equal(tau.eval(), 1.0)
+        npt.assert_almost_equal(sigma.eval(), 1.0)
+
+        # Test exception upon passing both sigma and tau
+        msg = "Can't pass both tau and sigma"
+        with pytest.raises(ValueError, match=msg):
+            _, _ = get_tau_sigma(sigma=1.0, tau=1.0)
+
+        # These are regression test for #6988: Check that get_tau_sigma works
+        # for lists of tensors
+        sigma = [pt.constant(2), pt.constant(2)]
+        expect_tau = np.array([0.25, 0.25])
+        tau, _ = get_tau_sigma(sigma=sigma)
+        npt.assert_almost_equal(tau.eval(), expect_tau)
+
+        tau = [pt.constant(2), pt.constant(2)]
+        expect_sigma = np.array([2.0, 2.0]) ** -0.5
+        _, sigma = get_tau_sigma(tau=tau)
+        npt.assert_almost_equal(sigma.eval(), expect_sigma)
 
     @pytest.mark.parametrize(
         "value,mu,sigma,nu,logp",
@@ -1063,10 +1076,10 @@ class TestMoments:
             ((2, 5), np.zeros((2, 5))),
         ],
     )
-    def test_flat_moment(self, size, expected):
+    def test_flat_support_point(self, size, expected):
         with pm.Model() as model:
             pm.Flat("x", size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "size, expected",
@@ -1076,10 +1089,10 @@ class TestMoments:
             ((2, 5), np.ones((2, 5))),
         ],
     )
-    def test_halfflat_moment(self, size, expected):
+    def test_halfflat_support_point(self, size, expected):
         with pm.Model() as model:
             pm.HalfFlat("x", size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "lower, upper, size, expected",
@@ -1090,10 +1103,10 @@ class TestMoments:
             (0, np.arange(1, 6), (2, 5), np.full((2, 5), np.arange(1, 6) / 2)),
         ],
     )
-    def test_uniform_moment(self, lower, upper, size, expected):
+    def test_uniform_support_point(self, lower, upper, size, expected):
         with pm.Model() as model:
             pm.Uniform("x", lower=lower, upper=upper, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, sigma, size, expected",
@@ -1104,10 +1117,10 @@ class TestMoments:
             (np.arange(5), np.arange(1, 6), (2, 5), np.full((2, 5), np.arange(5))),
         ],
     )
-    def test_normal_moment(self, mu, sigma, size, expected):
+    def test_normal_support_point(self, mu, sigma, size, expected):
         with pm.Model() as model:
             pm.Normal("x", mu=mu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "sigma, size, expected",
@@ -1118,10 +1131,10 @@ class TestMoments:
             (np.arange(1, 6), (2, 5), np.full((2, 5), np.arange(1, 6))),
         ],
     )
-    def test_halfnormal_moment(self, sigma, size, expected):
+    def test_halfnormal_support_point(self, sigma, size, expected):
         with pm.Model() as model:
             pm.HalfNormal("x", sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "nu, sigma, size, expected",
@@ -1132,10 +1145,10 @@ class TestMoments:
             (np.arange(1, 6), 1, None, np.full(5, 1)),
         ],
     )
-    def test_halfstudentt_moment(self, nu, sigma, size, expected):
+    def test_halfstudentt_support_point(self, nu, sigma, size, expected):
         with pm.Model() as model:
             pm.HalfStudentT("x", nu=nu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, sigma, lower, upper, size, expected",
@@ -1146,10 +1159,10 @@ class TestMoments:
             (1, 1, [-np.inf, -np.inf, -np.inf], 10, None, np.full(3, 9)),
         ],
     )
-    def test_truncatednormal_moment(self, mu, sigma, lower, upper, size, expected):
+    def test_truncatednormal_support_point(self, mu, sigma, lower, upper, size, expected):
         with pm.Model() as model:
             pm.TruncatedNormal("x", mu=mu, sigma=sigma, lower=lower, upper=upper, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, beta, size, expected",
@@ -1160,10 +1173,10 @@ class TestMoments:
             (1, np.arange(1, 6), (2, 5), np.full((2, 5), 1 / np.arange(2, 7))),
         ],
     )
-    def test_beta_moment(self, alpha, beta, size, expected):
+    def test_beta_support_point(self, alpha, beta, size, expected):
         with pm.Model() as model:
             pm.Beta("x", alpha=alpha, beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "lam, size, expected",
@@ -1174,10 +1187,10 @@ class TestMoments:
             (np.arange(1, 5), (2, 4), np.full((2, 4), 1 / np.arange(1, 5))),
         ],
     )
-    def test_exponential_moment(self, lam, size, expected):
+    def test_exponential_support_point(self, lam, size, expected):
         with pm.Model() as model:
             pm.Exponential("x", lam=lam, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, b, size, expected",
@@ -1188,10 +1201,10 @@ class TestMoments:
             (np.arange(5), np.arange(1, 6), (2, 5), np.full((2, 5), np.arange(5))),
         ],
     )
-    def test_laplace_moment(self, mu, b, size, expected):
+    def test_laplace_support_point(self, mu, b, size, expected):
         with pm.Model() as model:
             pm.Laplace("x", mu=mu, b=b, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, nu, sigma, size, expected",
@@ -1208,10 +1221,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_studentt_moment(self, mu, nu, sigma, size, expected):
+    def test_studentt_support_point(self, mu, nu, sigma, size, expected):
         with pm.Model() as model:
             pm.StudentT("x", mu=mu, nu=nu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, beta, size, expected",
@@ -1222,10 +1235,10 @@ class TestMoments:
             (np.arange(5), np.arange(1, 6), (2, 5), np.full((2, 5), np.arange(5))),
         ],
     )
-    def test_cauchy_moment(self, alpha, beta, size, expected):
+    def test_cauchy_support_point(self, alpha, beta, size, expected):
         with pm.Model() as model:
             pm.Cauchy("x", alpha=alpha, beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "a, b, size, expected",
@@ -1237,10 +1250,10 @@ class TestMoments:
             (1, np.arange(1, 6), (2, 5), np.full((2, 5), 1 / np.arange(2, 7))),
         ],
     )
-    def test_kumaraswamy_moment(self, a, b, size, expected):
+    def test_kumaraswamy_support_point(self, a, b, size, expected):
         with pm.Model() as model:
             pm.Kumaraswamy("x", a=a, b=b, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, sigma, size, expected",
@@ -1256,10 +1269,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_lognormal_moment(self, mu, sigma, size, expected):
+    def test_lognormal_support_point(self, mu, sigma, size, expected):
         with pm.Model() as model:
             pm.LogNormal("x", mu=mu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "beta, size, expected",
@@ -1274,10 +1287,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_halfcauchy_moment(self, beta, size, expected):
+    def test_halfcauchy_support_point(self, beta, size, expected):
         with pm.Model() as model:
             pm.HalfCauchy("x", beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, beta, size, expected",
@@ -1293,10 +1306,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_gamma_moment(self, alpha, beta, size, expected):
+    def test_gamma_support_point(self, alpha, beta, size, expected):
         with pm.Model() as model:
             pm.Gamma("x", alpha=alpha, beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, beta, size, expected",
@@ -1307,10 +1320,10 @@ class TestMoments:
             (np.arange(1, 6), 1, None, np.array([0.5, 1, 1 / 2, 1 / 3, 1 / 4])),
         ],
     )
-    def test_inverse_gamma_moment(self, alpha, beta, size, expected):
+    def test_inverse_gamma_support_point(self, alpha, beta, size, expected):
         with pm.Model() as model:
             pm.InverseGamma("x", alpha=alpha, beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, m, size, expected",
@@ -1326,10 +1339,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_pareto_moment(self, alpha, m, size, expected):
+    def test_pareto_support_point(self, alpha, m, size, expected):
         with pm.Model() as model:
             pm.Pareto("x", alpha=alpha, m=m, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, kappa, size, expected",
@@ -1340,10 +1353,10 @@ class TestMoments:
             (np.arange(4), np.arange(1, 5), (2, 4), np.full((2, 4), np.arange(4))),
         ],
     )
-    def test_vonmises_moment(self, mu, kappa, size, expected):
+    def test_vonmises_support_point(self, mu, kappa, size, expected):
         with pm.Model() as model:
             pm.VonMises("x", mu=mu, kappa=kappa, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, lam, phi, size, expected",
@@ -1355,10 +1368,10 @@ class TestMoments:
             (np.arange(1, 6), None, np.arange(1, 6), (2, 5), np.full((2, 5), np.arange(1, 6))),
         ],
     )
-    def test_wald_moment(self, mu, lam, phi, size, expected):
+    def test_wald_support_point(self, mu, lam, phi, size, expected):
         with pm.Model() as model:
             pm.Wald("x", mu=mu, lam=lam, phi=phi, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, beta, size, expected",
@@ -1377,10 +1390,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_weibull_moment(self, alpha, beta, size, expected):
+    def test_weibull_support_point(self, alpha, beta, size, expected):
         with pm.Model() as model:
             pm.Weibull("x", alpha=alpha, beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, s, size, expected",
@@ -1396,10 +1409,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_logistic_moment(self, mu, s, size, expected):
+    def test_logistic_support_point(self, mu, s, size, expected):
         with pm.Model() as model:
             pm.Logistic("x", mu=mu, s=s, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, nu, sigma, size, expected",
@@ -1411,10 +1424,10 @@ class TestMoments:
             (1, np.arange(1, 6), 1, (2, 5), np.full((2, 5), np.arange(2, 7))),
         ],
     )
-    def test_exgaussian_moment(self, mu, nu, sigma, size, expected):
+    def test_exgaussian_support_point(self, mu, nu, sigma, size, expected):
         with pm.Model() as model:
             pm.ExGaussian("x", mu=mu, sigma=sigma, nu=nu, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, beta, size, expected",
@@ -1431,10 +1444,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_gumbel_moment(self, mu, beta, size, expected):
+    def test_gumbel_support_point(self, mu, beta, size, expected):
         with pm.Model() as model:
             pm.Gumbel("x", mu=mu, beta=beta, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "c, lower, upper, size, expected",
@@ -1452,10 +1465,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_triangular_moment(self, c, lower, upper, size, expected):
+    def test_triangular_support_point(self, c, lower, upper, size, expected):
         with pm.Model() as model:
             pm.Triangular("x", c=c, lower=lower, upper=upper, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, sigma, size, expected",
@@ -1467,10 +1480,10 @@ class TestMoments:
             (np.arange(4), np.arange(1, 5), (2, 4), np.full((2, 4), sp.expit(np.arange(4)))),
         ],
     )
-    def test_logitnormal_moment(self, mu, sigma, size, expected):
+    def test_logitnormal_support_point(self, mu, sigma, size, expected):
         with pm.Model() as model:
             pm.LogitNormal("x", mu=mu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "x_points, pdf_points, size, expected",
@@ -1509,10 +1522,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_interpolated_moment(self, x_points, pdf_points, size, expected):
+    def test_interpolated_support_point(self, x_points, pdf_points, size, expected):
         with pm.Model() as model:
             pm.Interpolated("x", x_points=x_points, pdf_points=pdf_points, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, sigma, size, expected",
@@ -1523,10 +1536,10 @@ class TestMoments:
             (np.arange(5), np.ones(5), (2, 5), np.full((2, 5), np.arange(5) + 1.2703628454614782)),
         ],
     )
-    def test_moyal_moment(self, mu, sigma, size, expected):
+    def test_moyal_support_point(self, mu, sigma, size, expected):
         with pm.Model() as model:
             pm.Moyal("x", mu=mu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "alpha, mu, sigma, size, expected",
@@ -1550,10 +1563,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_skewnormal_moment(self, alpha, mu, sigma, size, expected):
+    def test_skewnormal_support_point(self, alpha, mu, sigma, size, expected):
         with pm.Model() as model:
             pm.SkewNormal("x", alpha=alpha, mu=mu, sigma=sigma, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "b, kappa, mu, size, expected",
@@ -1577,10 +1590,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_asymmetriclaplace_moment(self, b, kappa, mu, size, expected):
+    def test_asymmetriclaplace_support_point(self, b, kappa, mu, size, expected):
         with pm.Model() as model:
             pm.AsymmetricLaplace("x", b=b, kappa=kappa, mu=mu, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "nu, sigma, size, expected",
@@ -1616,7 +1629,7 @@ class TestMoments:
             ),
         ],
     )
-    def test_rice_moment(self, nu, sigma, size, expected):
+    def test_rice_support_point(self, nu, sigma, size, expected):
         with pm.Model() as model:
             pm.Rice("x", nu=nu, sigma=sigma, size=size)
 
@@ -1669,10 +1682,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_polyagamma_moment(self, h, z, size, expected):
+    def test_polyagamma_support_point(self, h, z, size, expected):
         with pm.Model() as model:
             pm.PolyaGamma("x", h=h, z=z, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
 
 class TestFlat(BaseTestDistributionRandom):
@@ -1851,7 +1864,7 @@ class TestHalfStudentT(BaseTestDistributionRandom):
     pymc_dist_params = {"nu": 5.0, "sigma": 2.0}
     expected_rv_op_params = {"nu": 5.0, "sigma": 2.0}
     reference_dist_params = {"df": 5.0, "loc": 0, "scale": 2.0}
-    reference_dist = lambda self: ft.partial(self.halfstudentt_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.halfstudentt_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_pymc_params_match_rv_op",
         "check_pymc_draws_match_reference",
@@ -2047,7 +2060,7 @@ class TestStudentTLam(BaseTestDistributionRandom):
     lam, sigma = get_tau_sigma(tau=2.0)
     pymc_dist_params = {"nu": 5.0, "mu": -1.0, "lam": lam}
     expected_rv_op_params = {"nu": 5.0, "mu": -1.0, "lam": sigma}
-    reference_dist_params = {"df": 5.0, "loc": -1.0, "scale": sigma}
+    reference_dist_params = {"df": 5.0, "loc": -1.0, "scale": sigma.eval()}
     reference_dist = seeded_scipy_distribution_builder("t")
     checks_to_run = ["check_pymc_params_match_rv_op"]
 
@@ -2074,7 +2087,7 @@ class TestLogitNormal(BaseTestDistributionRandom):
     pymc_dist_params = {"mu": 5.0, "sigma": 10.0}
     expected_rv_op_params = {"mu": 5.0, "sigma": 10.0}
     reference_dist_params = {"loc": 5.0, "scale": 10.0}
-    reference_dist = lambda self: ft.partial(self.logit_normal_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.logit_normal_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_pymc_params_match_rv_op",
         "check_pymc_draws_match_reference",
@@ -2145,7 +2158,7 @@ class TestBeta(BaseTestDistributionRandom):
     expected_rv_op_params = {"alpha": 2.0, "beta": 5.0}
     reference_dist_params = {"a": 2.0, "b": 5.0}
     size = 15
-    reference_dist = lambda self: ft.partial(clipped_beta_rvs, random_state=self.get_random_state())
+    reference_dist = lambda self: ft.partial(clipped_beta_rvs, random_state=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_pymc_params_match_rv_op",
         "check_pymc_draws_match_reference",
@@ -2345,7 +2358,7 @@ class TestPolyaGamma(BaseTestDistributionRandom):
     pymc_dist_params = {"h": 1.0, "z": 0.0}
     expected_rv_op_params = {"h": 1.0, "z": 0.0}
     reference_dist_params = {"h": 1.0, "z": 0.0}
-    reference_dist = lambda self: ft.partial(self.polyagamma_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.polyagamma_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_pymc_params_match_rv_op",
         "check_pymc_draws_match_reference",
@@ -2366,7 +2379,7 @@ class TestInterpolated(BaseTestDistributionRandom):
     pymc_dist_params = {"x_points": x_points, "pdf_points": pdf_points}
     reference_dist_params = {"mu": mu, "sigma": sigma}
 
-    reference_dist = lambda self: ft.partial(self.interpolated_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.interpolated_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_rv_size",
         "check_draws",
@@ -2375,7 +2388,6 @@ class TestInterpolated(BaseTestDistributionRandom):
     def check_draws(self):
         for mu in R.vals:
             for sigma in Rplus.vals:
-                # pylint: disable=cell-var-from-loop
                 rng = self.get_random_state()
 
                 def ref_rand(size):
