@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,14 +14,12 @@
 
 import warnings
 
-from contextlib import ExitStack as does_not_raise
-
 import numpy as np
 import pytensor
 import pytest
 import scipy.stats as st
 
-from numpy.testing import assert_allclose
+from numpy.testing import assert_allclose, assert_almost_equal
 from pytensor import tensor as pt
 from pytensor.tensor import TensorVariable
 from pytensor.tensor.random.op import RandomVariable
@@ -81,7 +79,7 @@ from pymc.testing import (
     Rplusbig,
     Simplex,
     Unit,
-    assert_moment_is_expected,
+    assert_support_point_is_expected,
     check_logcdf,
     check_logp,
     check_selfconsistency_discrete_logcdf,
@@ -266,7 +264,7 @@ class TestMixture:
         # component shape is either (4, 2, 3), (2, 3)
         # weights shape is either (4, 2) or (2,)
         if size is not None:
-            expected_shape = size + (3,)
+            expected_shape = (*size, 3)
         elif component.ndim == 3 or weights.ndim == 2:
             expected_shape = (4, 3)
         else:
@@ -318,7 +316,7 @@ class TestMixture:
         # components[0] shape is either (4, 3) or (3,)
         # weights shape is either (4, 2) or (2,)
         if size is not None:
-            expected_shape = size + (3,)
+            expected_shape = (*size, 3)
         elif components[0].ndim == 2 or weights.ndim == 2:
             expected_shape = (4, 3)
         else:
@@ -424,7 +422,7 @@ class TestMixture:
         draws = mix.eval()
         expected_shape = (5, 4) if univariate else (5, 4, 3)
         if expand:
-            expected_shape = expected_shape + (3,)
+            expected_shape = (*expected_shape, 3)
         assert draws.shape == expected_shape
         assert np.unique(draws).size == draws.size
 
@@ -613,15 +611,8 @@ class TestMixture:
             ppc = sample_posterior_predictive(
                 n_samples * [self.get_initial_point(model)], return_inferencedata=False
             )
-        assert (
-            ppc["x_obs"].shape
-            == (
-                1,
-                n_samples,
-            )
-            + X.shape
-        )
-        assert prior["x_obs"].shape == (n_samples,) + X.shape
+        assert ppc["x_obs"].shape == (1, n_samples, *X.shape)
+        assert prior["x_obs"].shape == (n_samples, *X.shape)
         assert prior["mu0"].shape == (n_samples, D)
         assert prior["chol_cov_0"].shape == (n_samples, D * (D + 1) // 2)
 
@@ -818,7 +809,7 @@ class TestNormalMixture:
     def test_normal_mixture_nd(self, seeded_test, nd, ncomp):
         nd = to_tuple(nd)
         ncomp = int(ncomp)
-        comp_shape = nd + (ncomp,)
+        comp_shape = (*nd, ncomp)
         test_mus = np.random.randn(*comp_shape)
         test_taus = np.random.gamma(1, 1, size=comp_shape)
         observed = generate_normal_mixture_data(
@@ -1155,7 +1146,7 @@ class TestMixtureMoments:
     def test_single_univariate_component(self, weights, comp_dists, size, expected):
         with Model() as model:
             Mixture("x", weights, comp_dists, size=size)
-        assert_moment_is_expected(model, expected, check_finite_logp=False)
+        assert_support_point_is_expected(model, expected, check_finite_logp=False)
 
     @pytest.mark.parametrize(
         "weights, comp_dists, size, expected",
@@ -1208,7 +1199,7 @@ class TestMixtureMoments:
     def test_list_univariate_components(self, weights, comp_dists, size, expected):
         with Model() as model:
             Mixture("x", weights, comp_dists, size=size)
-        assert_moment_is_expected(model, expected, check_finite_logp=False)
+        assert_support_point_is_expected(model, expected, check_finite_logp=False)
 
     @pytest.mark.parametrize(
         "weights, comp_dists, size, expected",
@@ -1244,7 +1235,7 @@ class TestMixtureMoments:
     def test_single_multivariate_component(self, weights, comp_dists, size, expected):
         with Model() as model:
             Mixture("x", weights, comp_dists, size=size)
-        assert_moment_is_expected(model, expected, check_finite_logp=False)
+        assert_support_point_is_expected(model, expected, check_finite_logp=False)
 
     @pytest.mark.parametrize(
         "weights, comp_dists, size, expected",
@@ -1290,7 +1281,7 @@ class TestMixtureMoments:
     def test_list_multivariate_components(self, weights, comp_dists, size, expected):
         with Model() as model:
             Mixture("x", weights, comp_dists, size=size)
-        assert_moment_is_expected(model, expected, check_finite_logp=False)
+        assert_support_point_is_expected(model, expected, check_finite_logp=False)
 
 
 class TestMixtureDefaultTransforms:
@@ -1332,7 +1323,7 @@ class TestMixtureDefaultTransforms:
             mix2 = Mixture("mix2", [0.3, 0.7][::-1], comp_dists[::-1])
 
         ip = model.initial_point()
-        # We want an informative moment, other than zero
+        # We want an informative support_point, other than zero
         assert ip["mix1_interval__"] != 0
 
         expected_mix_ip = (
@@ -1504,10 +1495,10 @@ class TestZeroInflatedMixture:
             (0.2, np.arange(1, 5) * 5, (2, 4), np.full((2, 4), np.arange(1, 5))),
         ],
     )
-    def test_zero_inflated_poisson_moment(self, psi, mu, size, expected):
+    def test_zero_inflated_poisson_support_point(self, psi, mu, size, expected):
         with Model() as model:
             ZeroInflatedPoisson("x", psi=psi, mu=mu, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "psi, n, p, size, expected",
@@ -1524,10 +1515,10 @@ class TestZeroInflatedMixture:
             ),
         ],
     )
-    def test_zero_inflated_binomial_moment(self, psi, n, p, size, expected):
+    def test_zero_inflated_binomial_support_point(self, psi, n, p, size, expected):
         with Model() as model:
             ZeroInflatedBinomial("x", psi=psi, n=n, p=p, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "psi, mu, alpha, size, expected",
@@ -1550,10 +1541,10 @@ class TestZeroInflatedMixture:
             ),
         ],
     )
-    def test_zero_inflated_negative_binomial_moment(self, psi, mu, alpha, size, expected):
+    def test_zero_inflated_negative_binomial_support_point(self, psi, mu, alpha, size, expected):
         with Model() as model:
             ZeroInflatedNegativeBinomial("x", psi=psi, mu=mu, alpha=alpha, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "dist, non_psi_args",
@@ -1647,7 +1638,7 @@ class TestHurdleMixtures:
         ],
     )
     def test_hurdle_logp_at_zero(self, dist, psi, non_psi_args):
-        assert logp(dist(psi=psi, **non_psi_args), 0).eval() == np.log(1 - psi)
+        assert_almost_equal(logp(dist(psi=psi, **non_psi_args), 0).eval(), np.log(1 - psi))
 
     @pytest.mark.parametrize(
         "dist, psi, non_psi_args",
