@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -321,7 +321,7 @@ class TestSimulator:
     @pytest.mark.parametrize("mu", [0, np.arange(3)], ids=str)
     @pytest.mark.parametrize("sigma", [1, np.array([1, 2, 5])], ids=str)
     @pytest.mark.parametrize("size", [None, 3, (5, 3)], ids=str)
-    def test_simulator_moment(self, seeded_test, mu, sigma, size):
+    def test_simulator_support_point(self, seeded_test, mu, sigma, size):
         def normal_sim(rng, mu, sigma, size):
             return rng.normal(mu, sigma, size=size)
 
@@ -331,15 +331,15 @@ class TestSimulator:
         fn = make_initial_point_fn(
             model=model,
             return_transformed=False,
-            default_strategy="moment",
+            default_strategy="support_point",
         )
 
         random_draw = model["x"].eval()
         result = fn(0)["x"]
         assert result.shape == random_draw.shape
 
-        # We perform a z-test between the moment and expected mean from a sample of 10 draws
-        # This test fails if the number of samples averaged in moment(Simulator)
+        # We perform a z-test between the support_point and expected mean from a sample of 10 draws
+        # This test fails if the number of samples averaged in support_point(Simulator)
         # is much smaller than 10, but would not catch the case where the number of samples
         # is higher than the expected 10
 
