@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ from pymc.model import Model
 from pymc.pytensorf import floatX
 from pymc.sampling.forward import draw, sample_posterior_predictive
 from pymc.sampling.mcmc import sample
-from pymc.testing import assert_moment_is_expected, select_by_precision
+from pymc.testing import assert_support_point_is_expected, select_by_precision
 
 # Turn all warnings into errors for this module
 # Ignoring NumPy deprecation warning tracked in https://github.com/pymc-devs/pytensor/issues/146
@@ -378,12 +378,14 @@ class TestRandomWalk:
             ),
         ],
     )
-    def test_moment(self, init_dist, innovation_dist, steps, size, expected, check_finite_logp):
+    def test_support_point(
+        self, init_dist, innovation_dist, steps, size, expected, check_finite_logp
+    ):
         with Model() as model:
             RandomWalk(
                 "x", init_dist=init_dist, innovation_dist=innovation_dist, steps=steps, size=size
             )
-        assert_moment_is_expected(model, expected, check_finite_logp=check_finite_logp)
+        assert_support_point_is_expected(model, expected, check_finite_logp=check_finite_logp)
 
 
 class TestPredefinedRandomWalk:
@@ -429,11 +431,9 @@ class TestPredefinedRandomWalk:
         with pm.Model() as model:
             mu = Normal("mu", 0.0, 1.0, shape=3)
             sd_dist = Exponential.dist(1.0, shape=3)
-            # pylint: disable=unpacking-non-sequence
             chol, corr, stds = LKJCholeskyCov(
                 "chol_cov", n=3, eta=2, sd_dist=sd_dist, compute_corr=True
             )
-            # pylint: enable=unpacking-non-sequence
             with pytest.warns(UserWarning, match="Initial distribution not specified"):
                 if param == "chol":
                     mv = MvGaussianRandomWalk("mv", mu, chol=chol, shape=(10, 7, 3))
@@ -700,11 +700,11 @@ class TestAR:
             ((5, 2), np.full((5, 2, 7), [[2.0], [4.0]])),
         ],
     )
-    def test_moment(self, size, expected):
+    def test_support_point(self, size, expected):
         with Model() as model:
             init_dist = DiracDelta.dist([[1.0, 2.0], [3.0, 4.0]])
             AR("x", rho=[0, 0], init_dist=init_dist, steps=5, size=size)
-        assert_moment_is_expected(model, expected, check_finite_logp=False)
+        assert_support_point_is_expected(model, expected, check_finite_logp=False)
 
     def test_init_deprecated_arg(self):
         with pytest.warns(FutureWarning, match="init parameter is now called init_dist"):
@@ -820,7 +820,7 @@ class TestGARCH11:
             ((5, 2), np.zeros((5, 2, 8))),
         ],
     )
-    def test_moment(self, size, expected):
+    def test_support_point(self, size, expected):
         with Model() as model:
             GARCH11(
                 "x",
@@ -831,7 +831,7 @@ class TestGARCH11:
                 steps=7,
                 size=size,
             )
-        assert_moment_is_expected(model, expected, check_finite_logp=True)
+        assert_support_point_is_expected(model, expected, check_finite_logp=True)
 
     def test_change_dist_size(self):
         base_dist = GARCH11.dist(
@@ -954,7 +954,7 @@ class TestEulerMaruyama:
                 xs.append(xs[-1] + f * dt + np.sqrt(dt) * g * wt[i])
             return np.array(xs)
 
-        sde = lambda x, lam: (lam * x, sig2)
+        sde = lambda x, lam: (lam * x, sig2)  # noqa E731
         x = floatX(_gen_sde_path(sde, (lam,), dt, N, 5.0))
         z = x + numpy_rng.standard_normal(size=x.size) * sig2
         # build model
