@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -11,9 +11,11 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
+import logging
+import re
 import warnings
 
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Optional
 from unittest import mock
 
 import arviz as az
@@ -35,9 +37,7 @@ from pymc.distributions.multivariate import PosDefMatrix
 from pymc.sampling.jax import (
     _get_batched_jittered_initial_points,
     _get_log_likelihood,
-    _numpyro_nuts_defaults,
     _replace_shared_variables,
-    _update_numpyro_nuts_kwargs,
     get_jaxified_graph,
     get_jaxified_logp,
     sample_blackjax_nuts,
@@ -154,6 +154,47 @@ def test_deterministic_samples(sampler):
     assert np.allclose(trace.posterior["b"].values, trace.posterior["a"].values / 2)
 
 
+@pytest.mark.parametrize(
+    "sampler",
+    [
+        sample_blackjax_nuts,
+        sample_numpyro_nuts,
+    ],
+)
+def test_initvals_without_jitter(sampler):
+    pytensor.config.on_opt_error = "raise"
+    np.random.seed(13244)
+
+    obs = np.random.normal(10, 2, size=100)
+    obs_at = pytensor.shared(obs, borrow=True, name="obs")
+    initvals = {"a": -3}
+    with pm.Model() as model:
+        a = pm.Uniform("a", -20, 20)
+        b = pm.Deterministic("b", a / 2.0)
+        c = pm.Normal("c", a, sigma=1.0, observed=obs_at)
+
+        trace1 = sampler(
+            chains=1,
+            tune=1,
+            draws=1,
+            random_seed=1322,
+            initvals=initvals,
+            jitter=False,
+            keep_untransformed=True,
+        )
+        trace2 = sampler(
+            chains=1,
+            tune=1,
+            draws=1,
+            random_seed=1322,
+            initvals=initvals,
+            keep_untransformed=True,
+        )
+
+    assert np.allclose(trace1.posterior["a"].values[0], -3)
+    assert not np.allclose(trace2.posterior["a"].values[0], -3)
+
+
 def test_get_jaxified_graph():
     # Check that jaxifying a graph does not emit the Supervisor Warning. This test can
     # be removed once https://github.com/aesara-devs/aesara/issues/637 is sorted.
@@ -256,7 +297,7 @@ def model_test_idata_kwargs() -> pm.Model:
 def test_idata_kwargs(
     model_test_idata_kwargs: pm.Model,
     sampler: Callable[..., az.InferenceData],
-    idata_kwargs: Dict[str, Any],
+    idata_kwargs: dict[str, Any],
     postprocessing_backend: Optional[str],
 ):
     idata: Optional[az.InferenceData] = None
@@ -359,29 +400,6 @@ def test_seeding(chains, random_seed, sampler):
         assert np.all(result2.posterior["x"].sel(chain=0) != result2.posterior["x"].sel(chain=1))
 
 
-@pytest.mark.parametrize(
-    "nuts_kwargs",
-    [
-        {"adapt_step_size": False},
-        {"adapt_mass_matrix": True},
-        {"dense_mass": True},
-        {"adapt_step_size": False, "adapt_mass_matrix": True, "dense_mass": True},
-        {"fake-key": "fake-value"},
-    ],
-)
-def test_update_numpyro_nuts_kwargs(nuts_kwargs: Dict[str, Any]):
-    original_kwargs = nuts_kwargs.copy()
-    new_kwargs = _update_numpyro_nuts_kwargs(nuts_kwargs)
-
-    # Maintains original key-value pairs.
-    for k, v in original_kwargs.items():
-        assert new_kwargs[k] == v
-
-    for k, v in _numpyro_nuts_defaults().items():
-        if k not in original_kwargs:
-            assert new_kwargs[k] == v
-
-
 @mock.patch("numpyro.infer.MCMC")
 def test_numpyro_nuts_kwargs_are_used(mocked: mock.MagicMock):
     mocked.side_effect = MCMC
@@ -471,3 +489,17 @@ def test_sample_partially_observed():
     assert idata.observed_data["x_observed"].shape == (2,)
     assert idata.posterior["x_unobserved"].shape == (1, 10, 1)
     assert idata.posterior["x"].shape == (1, 10, 3)
+
+
+@pytest.mark.parametrize("nuts_sampler", ("numpyro", "blackjax"))
+def test_convergence_warnings(caplog, nuts_sampler):
+    with pm.Model() as m:
+        # Model that should diverge
+        sigma = pm.Normal("sigma", initval=3, transform=None)
+        pm.Normal("obs", mu=0, sigma=sigma, observed=[0.99, 1.0, 1.01])
+
+        with caplog.at_level(logging.WARNING, logger="pymc"):
+            pm.sample(nuts_sampler=nuts_sampler, random_seed=581)
+
+    [record] = caplog.records
+    assert re.match(r"There were \d+ divergences after tuning", record.message)
