@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -16,7 +16,6 @@ import unittest.mock as mock
 import warnings
 
 from contextlib import ExitStack as does_not_raise
-from copy import copy
 
 import numpy as np
 import numpy.testing as npt
@@ -768,7 +767,7 @@ class TestAssignStepMethods:
         assert not isinstance(steps, NUTS)
 
         # add back nuts
-        pm.STEP_METHODS = step_methods + [NUTS]
+        pm.STEP_METHODS = [*step_methods, NUTS]
 
         with pm.Model() as model:
             pm.Normal("x", 0, 1)
