@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -108,7 +108,7 @@ def test_hashing_of_rv_tuples():
         mu = pm.Normal("mu", 0, 1)
         sigma = pm.Gamma("sigma", 1, 2)
         dd = pm.Normal("dd", observed=obs)
-        for freerv in [mu, sigma, dd] + pmodel.free_RVs:
+        for freerv in [mu, sigma, dd, *pmodel.free_RVs]:
             for structure in [
                 freerv,
                 {"alpha": freerv, "omega": None},
@@ -156,8 +156,12 @@ def test_unset_repr(capsys):
     assert "a=UNSET" in captured.out
 
 
-def test_dataset_to_point_list():
-    ds = xarray.Dataset()
+@pytest.mark.parametrize("input_type", ("dict", "Dataset"))
+def test_dataset_to_point_list(input_type):
+    if input_type == "dict":
+        ds = {}
+    elif input_type == "Dataset":
+        ds = xarray.Dataset()
     ds["A"] = xarray.DataArray([[1, 2, 3]] * 2, dims=("chain", "draw"))
     pl, _ = dataset_to_point_list(ds, sample_dims=["chain", "draw"])
     assert isinstance(pl, list)
@@ -165,7 +169,20 @@ def test_dataset_to_point_list():
     assert isinstance(pl[0], dict)
     assert isinstance(pl[0]["A"], np.ndarray)
 
+
+def test_transposed_dataset_to_point_list():
+    ds = xarray.Dataset()
+    ds["A"] = xarray.DataArray([[[1, 2, 3], [2, 3, 4]]] * 5, dims=("team", "draw", "chain"))
+    pl, _ = dataset_to_point_list(ds, sample_dims=["chain", "draw"])
+    assert isinstance(pl, list)
+    assert len(pl) == 6
+    assert isinstance(pl[0], dict)
+    assert isinstance(pl[0]["A"], np.ndarray)
+
+
+def test_dataset_to_point_list_str_key():
     # Check that non-str keys are caught
+    ds = xarray.Dataset()
     ds[3] = xarray.DataArray([1, 2, 3])
     with pytest.raises(ValueError, match="must be str"):
         dataset_to_point_list(ds, sample_dims=["chain", "draw"])
